Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Amplify UI Builder.

Actions, resources, and condition keys for AWS Amplify UI Builder - Service Authorization Reference

# Actions, resources, and condition keys for AWS Amplify UI Builder

AWS Amplify UI Builder (service prefix: `amplifyuibuilder` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Amplify UI Builder
- Resource types defined by AWS Amplify UI Builder
- Condition keys for AWS Amplify UI Builder

## Actions defined by AWS Amplify UI Builder

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateComponent | Grants permission to create a component | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateTheme | Grants permission to create a theme | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteComponent | Grants permission to delete a component | Write | ComponentResource* |  |
DeleteTheme | Grants permission to delete a theme | Write | ThemeResource* |  |
ExchangeCodeForToken | Grants permission to exchange a code for a token | Write |  |  |
ExportComponents | Grants permission to export components | Read |  |  |
ExportThemes | Grants permission to export themes | Read |  |  |
GetComponent | Grants permission to get an existing component | Read | ComponentResource* |  |
GetTheme | Grants permission to get an existing theme | Read | ThemeResource* |  |
ListComponents | Grants permission to list the components for an app | List |  |  |
ListTagsForResource | Grants permission to list the tags for a resource | Read | ComponentResource |  |
ThemeResource |  |
ListThemes | Grants permission to list the themes for an app | List |  |  |
RefreshToken | Grants permission to refresh an access token | Write |  |  |
TagResource | Grants permission to tag a resource | Tagging | ComponentResource |  |
ThemeResource |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag a resource | Tagging | ComponentResource |  |
ThemeResource |  |
| aws:TagKeys |
UpdateComponent | Grants permission to update a component | Write | ComponentResource* |  |
UpdateTheme | Grants permission to update a theme | Write | ThemeResource* |  |

## Resource types defined by AWS Amplify UI Builder

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
ComponentResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/components/$ { Id}` | amplifyuibuilder:AppId amplifyuibuilder:ComponentsId amplifyuibuilder:EnvironmentName aws:ResourceTag/${TagKey}
ThemeResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/themes/$ { Id}` | amplifyuibuilder:AppId amplifyuibuilder:EnvironmentName amplifyuibuilder:ThemesId aws:ResourceTag/${TagKey}

## Condition keys for AWS Amplify UI Builder

AWS Amplify UI Builder defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
amplifyuibuilder:AppId | Filters access by the app ID | String
amplifyuibuilder:ComponentsId | Filters access by the component ID | String
amplifyuibuilder:EnvironmentName | Filters access by the backend environment name | String
amplifyuibuilder:ThemesId | Filters access by the theme ID | String
aws:RequestTag/${TagKey} | Filters access based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access based on the tags associated with the resource | String
aws:TagKeys | Filters access based on the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.